@@ -1444,38 +1444,10 @@ class PppoeClient:
     def __init__(self, pb=None, errctx=None, **kwargs):
         self.pb = pb if pb else network_poller_pb2.PppoeClient()
         self.errctx = errctx
+        self.network_prefixes = Repeated(None, self.pb.network_prefixes, self.errctx)
         for key, value in kwargs.items():
             setattr(self, key, value)
 
-    @property
-    def if_name(self):
-        return self.pb.if_name if self.pb.HasField('if_name') else None
-
-    @if_name.setter
-    def if_name(self, value):
-        if value is not None:
-            self.pb.if_name = value
-        else:
-            self.pb.ClearField('if_name')
-
-    @property
-    def if_index(self):
-        return self.pb.if_index if self.pb.HasField('if_index') else None
-
-    @if_index.setter
-    def if_index(self, value):
-        if value is not None:
-            if value >= 0 and int.bit_length(value) < 32:
-                self.pb.if_index = value
-            elif self.errctx:
-                self.errctx.add(
-                    network_poller_pb2.PollError.ERROR_BAD_DATA_RANGE,
-                    'Invalid value for NetworkElementUpdate.PppoeClient.if_index',
-                    value=value,
-                    metric_name='NetworkElementUpdate.PppoeClient.if_index')
-        else:
-            self.pb.ClearField('if_index')
-
     @property
     def username(self):
         return self.pb.username
@@ -1496,17 +1468,6 @@ class PppoeClient:
         else:
             self.pb.ClearField('mac_address')
 
-    @property
-    def ip_address(self):
-        return self.pb.ip_address if self.pb.HasField('ip_address') else None
-
-    @ip_address.setter
-    def ip_address(self, value):
-        if value is not None:
-            self.pb.ip_address = value
-        else:
-            self.pb.ClearField('ip_address')
-
 
 class NetworkElement:
 
